==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/tab/tab.js <==
import {
    Action,
    ActionUtil,
    Expectation,
    WaitCondition
} from 'protractor-base-dsl';

const tabSelector = '.xl-react-tab-system-default';
const tabSelectorBindings = `${tabSelector} .testBindings`;

export const closeTab = (tabNumber) =>
    Action.click(`${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber}) .xl-react-btn-close`);

export const expectActiveTabTitle = (text) =>
    Expectation.textEquals(`${tabSelector} .active .tab-title`, text);

export const expectBlueSkin = () =>
    Expectation.displayed(`${tabSelector} .blue-skin`);

export const expectDefaultSkin = () =>
    Expectation.displayed(`${tabSelector} .default-skin`);

export const expectNoneSkin = () =>
    Expectation.displayed(`${tabSelector} .none-skin`);

export const expectUnderlinedSkin = () =>
    Expectation.displayed(`${tabSelector} .underlined-skin`);

export const expectNoBlueSkin = () =>
    Expectation.notPresent(`${tabSelector} .blue-skin`);

export const expectNoDefaultSkin = () =>
    Expectation.notPresent(`${tabSelector} .default-skin`);

export const expectNoNoneSkin = () =>
    Expectation.notPresent(`${tabSelector} .none-skin`);

export const expectNoUnderlinedSkin = () =>
    Expectation.notPresent(`${tabSelector} .underlined-skin`);

export const expectSpinner = () =>
    Expectation.displayed(`${tabSelector} .active .xl-react-widget-spinner`);

export const expectNoSpinner = () =>
    Expectation.notPresent(`${tabSelector} .active .xl-react-widget-spinner`);

export const selectSkin = (value) =>
    Action.click(`${tabSelectorBindings} .radioButtonGroup input[name="skin"][value="${value}"]`);

export const selectBlueSkin = () => selectSkin('blue');

export const selectDefaultSkin = () => selectSkin('default');

export const selectNoneSkin = () => selectSkin('none');

export const selectUnderlinedSkin = () => selectSkin('underlined');

export const tabTitleExpectation = (tabNumber, title) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    return WaitCondition.textEquals(selector, title);
};

export const expectTabTitle = (tabNumber, title) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    Expectation.textEquals(selector, title);
};

export const expectTabFullTitle = (tabNumber, fullTitle) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    return Expectation.attributeEquals(selector, 'title', fullTitle);
};

export const toggleLoadingState = () =>
    Action.click(`${tabSelectorBindings} .toggle-loading-state-btn`);

export const waitTabNotPresent = (tabNumber) =>
    Expectation.notPresent(`${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`);

export const addNewTab = (newTabNumber) => {
    const action = () => Action.click(`${tabSelector} .btn-add-new-tab`);
    const condition = () => tabTitleExpectation(newTabNumber, 'New Tab');
    ActionUtil.repeatAction(action, condition);
    return expectActiveTabTitle('New Tab');
};

const Tab = {
    addNewTab,
    closeTab,
    expectActiveTabTitle,
    expectBlueSkin,
    expectDefaultSkin,
    expectNoBlueSkin,
    expectNoDefaultSkin,
    expectNoneSkin,
    expectNoNoneSkin,
    expectNoSpinner,
    expectNoUnderlinedSkin,
    expectSpinner,
    expectTabFullTitle,
    expectTabTitle,
    expectUnderlinedSkin,
    selectBlueSkin,
    selectDefaultSkin,
    selectNoneSkin,
    selectSkin,
    selectUnderlinedSkin,
    tabTitleExpectation,
    toggleLoadingState,
    waitTabNotPresent
};

export default Tab;
global.Tab = Tab;

==> xl-react-components-0.21.16.tgz: package/tests/e2e/dsl/component/tab/tab.js <==
import {
    Action,
    ActionUtil,
    Expectation,
    WaitCondition
} from 'protractor-base-dsl';

const tabSelector = '.xl-react-tab-system-default';
const tabSelectorBindings = `${tabSelector} .testBindings`;

export const closeTab = (tabNumber) =>
    Action.click(`${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber}) .close-icon`);

export const expectActiveTabTitle = (text) =>
    Expectation.textEquals(`${tabSelector} .active .tab-title`, text);

export const expectBlueSkin = () =>
    Expectation.displayed(`${tabSelector} .blue-skin`);

export const expectDefaultSkin = () =>
    Expectation.displayed(`${tabSelector} .default-skin`);

export const expectNoneSkin = () =>
    Expectation.displayed(`${tabSelector} .none-skin`);

export const expectUnderlinedSkin = () =>
    Expectation.displayed(`${tabSelector} .underlined-skin`);

export const expectNoBlueSkin = () =>
    Expectation.notPresent(`${tabSelector} .blue-skin`);

export const expectNoDefaultSkin = () =>
    Expectation.notPresent(`${tabSelector} .default-skin`);

export const expectNoNoneSkin = () =>
    Expectation.notPresent(`${tabSelector} .none-skin`);

export const expectNoUnderlinedSkin = () =>
    Expectation.notPresent(`${tabSelector} .underlined-skin`);

export const expectSpinner = () =>
    Expectation.displayed(`${tabSelector} .active .xl-react-widget-spinner`);

export const expectNoSpinner = () =>
    Expectation.notPresent(`${tabSelector} .active .xl-react-widget-spinner`);

export const selectSkin = (value) =>
    Action.click(`${tabSelectorBindings} .radioButtonGroup input[name="skin"][value="${value}"]`);

export const selectBlueSkin = () => selectSkin('blue');

export const selectDefaultSkin = () => selectSkin('default');

export const selectNoneSkin = () => selectSkin('none');

export const selectUnderlinedSkin = () => selectSkin('underlined');

export const tabTitleExpectation = (tabNumber, title) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    return WaitCondition.textEquals(selector, title);
};

export const expectTabTitle = (tabNumber, title) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    Expectation.textEquals(selector, title);
};

export const expectTabFullTitle = (tabNumber, fullTitle) => {
    const selector = `${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`;
    return Expectation.attributeEquals(selector, 'title', fullTitle);
};

export const toggleLoadingState = () =>
    Action.click(`${tabSelectorBindings} .toggle-loading-state-btn`);

export const waitTabNotPresent = (tabNumber) =>
    Expectation.notPresent(`${tabSelector} .nav.nav-tabs li:nth-child(${tabNumber})`);

export const addNewTab = (newTabNumber) => {
    const action = () => Action.click(`${tabSelector} .btn-add-new-tab`);
    const condition = () => tabTitleExpectation(newTabNumber, 'New Tab');
    ActionUtil.repeatAction(action, condition);
    return expectActiveTabTitle('New Tab');
};

const Tab = {
    addNewTab,
    closeTab,
    expectActiveTabTitle,
    expectBlueSkin,
    expectDefaultSkin,
    expectNoBlueSkin,
    expectNoDefaultSkin,
    expectNoneSkin,
    expectNoNoneSkin,
    expectNoSpinner,
    expectNoUnderlinedSkin,
    expectSpinner,
    expectTabFullTitle,
    expectTabTitle,
    expectUnderlinedSkin,
    selectBlueSkin,
    selectDefaultSkin,
    selectNoneSkin,
    selectSkin,
    selectUnderlinedSkin,
    tabTitleExpectation,
    toggleLoadingState,
    waitTabNotPresent
};

export default Tab;
global.Tab = Tab;
